'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

exports.default = nbem;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Config Class
 */
var Config = function () {
  function Config() {
    _classCallCheck(this, Config);

    this.init();
  }

  /**
   * Init Config
   */


  _createClass(Config, [{
    key: 'init',
    value: function init() {
      this.separator = {
        element: '__',
        modifier: '--'
      };
    }

    /**
     * Set Separator
     *
     * @param element - element separator
     * @param [modifier] - modifier separator
     */

  }, {
    key: 'setSeparator',
    value: function setSeparator(element) {
      var modifier = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '--';

      this.separator = { element: element, modifier: modifier };
    }
  }]);

  return Config;
}();

var config = exports.config = new Config();

/**
 * nbem
 */
function nbem() {
  var clses = [];

  /**
   * nbem
   *
   * @param rawCls - raw classname
   * @param staticClses - static classes
   */
  function _nbem(rawCls, staticClses) {
    var ret = createBemClassName(clses, rawCls);
    clses = ret[0];
    if (typeof staticClses === 'string') {
      return ret[1] + ' ' + staticClses;
    } else if ((typeof staticClses === 'undefined' ? 'undefined' : _typeof(staticClses)) === 'object' && staticClses instanceof Array) {
      var scls = joinStaticClses(staticClses);
      if (scls) {
        return ret[1] + ' ' + scls;
      }
    }
    return ret[1];
  }

  return _nbem;
}

/**
 * Create Bem Class Name
 *
 * @param clses - bem class tree
 * @param rawCls - raw classname
 */
function createBemClassName(clses, rawCls) {
  var nests = rawCls.split('&');
  var length = nests.length - 1;
  var _clses = [].concat(clses);
  _clses[length] = nests[length];
  var cls = _clses.map(function (c, key) {
    if (key <= length) {
      return c.split(':').join(config.separator.modifier);
    }
  }).filter(function (c) {
    return c;
  }).join(config.separator.element);
  return [_clses, cls];
}

/**
 * Join Static ClassNames
 *
 * @param staticClses - static classnames
 */
function joinStaticClses(staticClses) {
  if (staticClses.every(function (c) {
    return typeof c === 'string';
  })) {
    return staticClses.join(' ');
  }
  return '';
}